@@ -31,13 +31,11 @@ functionSignature = {
         "properties": {
             "code": {
                 "type": "string",
-                "description": "Python code that integrates package folium to resolve my request. Greated maps are saved in html format",
+                "description": "Python code that integrates package folium to resolve my request. Created maps are saved in html format",
             },
         },
         "required": ["code"],
     },
 }
 
-config.pluginsWithFunctionCall.append("create_map")
-config.chatGPTApiFunctionSignatures.append(functionSignature)
-config.chatGPTApiAvailableFunctions["create_map"] = create_map
\ No newline at end of file
+config.addFunctionCall(name="create_map", signature=functionSignature, method=create_map)
\ No newline at end of file
