@@ -28,19 +28,17 @@ def create_statistical_graphics(function_args):
 
 functionSignature = {
     "name": "create_statistical_graphics",
-    "description": f'''Create statistical plots, such as pie charts or pie charts, to visualize statistical data''',
+    "description": f'''Create statistical plots, such as pie charts or bar charts, to visualize statistical data''',
     "parameters": {
         "type": "object",
         "properties": {
             "code": {
                 "type": "string",
-                "description": "Python code that integrates package seaborn to resolve my request. Use TkAgg as backend. Greated plots are saved in png format",
+                "description": "Python code that integrates package seaborn to resolve my request. Use TkAgg as backend. Created plots are saved in png format",
             },
         },
         "required": ["code"],
     },
 }
 
-config.pluginsWithFunctionCall.append("create_statistical_graphics")
-config.chatGPTApiFunctionSignatures.append(functionSignature)
-config.chatGPTApiAvailableFunctions["create_statistical_graphics"] = create_statistical_graphics
\ No newline at end of file
+config.addFunctionCall(name="create_statistical_graphics", signature=functionSignature, method=create_statistical_graphics)
\ No newline at end of file
