@@ -7,7 +7,7 @@ Convert simplified Chinese into traditional Chinese in text output
 try:
     from opencc import OpenCC
 except:
-    from cybertask.utils.install import *
+    from cybertask.utils.install import installmodule
     installmodule(f"--upgrade opencc")
 
 from cybertask import config
@@ -19,4 +19,4 @@ def convertToTraditionalChinese(text):
     else:
         return text
 
-config.chatGPTTransformers.append(convertToTraditionalChinese)
\ No newline at end of file
+config.outputTransformers.append(convertToTraditionalChinese)
\ No newline at end of file
